import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="dictop",
    version="0.2.2",
    description="DICT-OPERATION allow you select data value from a dict-instance with dot separated path, and update.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Chen Qi",
    author_email="chenqi@zencore.cn",
    maintainer="Chen Qi",
    maintainer_email="chenqi@zencore.cn",
    license="MIT",
    license_files=("LICENSE",),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["dictop"],
    install_requires=requires,
    packages=find_packages(".", exclude=["tests"]),
    py_modules=["dictop"],
)
